@@ -6,7 +6,7 @@ from typing import Any, Dict, Optional
 
 import click
 
-from .click_common import command, format_output, EnumType
+from .click_common import EnumType, command, format_output
 from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
