@@ -3,7 +3,7 @@ import logging
 import string
 from collections import defaultdict
 from datetime import time
-from typing import Optional, List
+from typing import List, Optional
 
 import click
 
@@ -12,65 +12,61 @@ from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
-MODEL_PRESSURE1 = 'chunmi.cooker.press1'
-MODEL_PRESSURE2 = 'chunmi.cooker.press2'
-MODEL_NORMAL1 = 'chunmi.cooker.normal1'
-MODEL_NORMAL2 = 'chunmi.cooker.normal2'
-MODEL_NORMAL3 = 'chunmi.cooker.normal3'
-MODEL_NORMAL4 = 'chunmi.cooker.normal4'
-MODEL_NORMAL5 = 'chunmi.cooker.normal5'
+MODEL_PRESSURE1 = "chunmi.cooker.press1"
+MODEL_PRESSURE2 = "chunmi.cooker.press2"
+MODEL_NORMAL1 = "chunmi.cooker.normal1"
+MODEL_NORMAL2 = "chunmi.cooker.normal2"
+MODEL_NORMAL3 = "chunmi.cooker.normal3"
+MODEL_NORMAL4 = "chunmi.cooker.normal4"
+MODEL_NORMAL5 = "chunmi.cooker.normal5"
 
 MODEL_PRESSURE = [MODEL_PRESSURE1, MODEL_PRESSURE2]
-MODEL_NORMAL = [MODEL_NORMAL1, MODEL_NORMAL2, MODEL_NORMAL3, MODEL_NORMAL4,
-                MODEL_NORMAL5]
+MODEL_NORMAL = [
+    MODEL_NORMAL1,
+    MODEL_NORMAL2,
+    MODEL_NORMAL3,
+    MODEL_NORMAL4,
+    MODEL_NORMAL5,
+]
 
 MODEL_NORMAL_GROUP1 = [MODEL_NORMAL2, MODEL_NORMAL5]
 MODEL_NORMAL_GROUP2 = [MODEL_NORMAL3, MODEL_NORMAL4]
 
 COOKING_STAGES = {
     0: {
-        'name': 'Quickly preheat',
-        'description': 'Increase temperature in a controlled manner to soften rice gradually',
+        "name": "Quickly preheat",
+        "description": "Increase temperature in a controlled manner to soften rice gradually",
     },
     1: {
-        'name': 'Water-absorbing',
-        'description': 'Increase temperature, to flesh grains with water',
-    },
-    2: {
-        'name': 'Boiling',
-        'description': 'Last high heating, to cook rice evenly',
+        "name": "Water-absorbing",
+        "description": "Increase temperature, to flesh grains with water",
     },
+    2: {"name": "Boiling", "description": "Last high heating, to cook rice evenly"},
     3: {
-        'name': 'Gelantinizing',
-        'description': 'Steaming under high temperature, to bring sweetness to grains',
-    },
-    4: {
-        'name': 'Braising',
-        'description': 'Absorb water at moderate temperature',
+        "name": "Gelantinizing",
+        "description": "Steaming under high temperature, to bring sweetness to grains",
     },
+    4: {"name": "Braising", "description": "Absorb water at moderate temperature"},
     5: {
-        'name': 'Boiling',
-        'description': 'Operate at full load to boil rice',
+        "name": "Boiling",
+        "description": "Operate at full load to boil rice",
         # Keep heating at high temperature. Let rice to receive
     },
     7: {
-        'name': 'Boiling',
-        'description': 'Operate at full load to boil rice',
+        "name": "Boiling",
+        "description": "Operate at full load to boil rice",
         # Keep heating at high temperature. Let rice to receive
     },
     8: {
-        'name': 'Warm up rice',
-        'description': 'Temperature control adjustment and cyclic heating '
-                       'achieve combination of taste, dolor and nutrition',
+        "name": "Warm up rice",
+        "description": "Temperature control adjustment and cyclic heating "
+        "achieve combination of taste, dolor and nutrition",
     },
     10: {
-        'name': 'High temperature gelatinization',
-        'description': 'High-temperature steam generates crystal clear rice g...',
+        "name": "High temperature gelatinization",
+        "description": "High-temperature steam generates crystal clear rice g...",
     },
-    16: {
-        'name': 'Cooking finished',
-        'description': '',
-    }
+    16: {"name": "Cooking finished", "description": ""},
 }
 
 
@@ -80,24 +76,24 @@ class CookerException(DeviceException):
 
 class OperationMode(enum.Enum):
     # Observed
-    Running = 'running'
-    Waiting = 'waiting'
-    AutoKeepWarm = 'autokeepwarm'
+    Running = "running"
+    Waiting = "waiting"
+    AutoKeepWarm = "autokeepwarm"
     # Potential candidates
-    Cooking = 'cooking'
-    Finish = 'finish'
-    FinishA = 'finisha'
-    KeepWarm = 'keepwarm'
-    KeepTemp = 'keep_temp'
-    Notice = 'notice'
-    Offline = 'offline'
-    Online = 'online'
-    PreCook = 'precook'
-    Resume = 'resume'
-    ResumeP = 'resumep'
-    Start = 'start'
-    StartP = 'startp'
-    Cancel = 'Отмена'
+    Cooking = "cooking"
+    Finish = "finish"
+    FinishA = "finisha"
+    KeepWarm = "keepwarm"
+    KeepTemp = "keep_temp"
+    Notice = "notice"
+    Offline = "offline"
+    Online = "online"
+    PreCook = "precook"
+    Resume = "resume"
+    ResumeP = "resumep"
+    Start = "start"
+    StartP = "startp"
+    Cancel = "Отмена"
 
 
 class TemperatureHistory:
@@ -130,7 +126,7 @@ class TemperatureHistory:
         ...
         """
         if not len(data) % 2:
-            self.data = [int(data[i:i + 2], 16) for i in range(0, len(data), 2)]
+            self.data = [int(data[i : i + 2], 16) for i in range(0, len(data), 2)]
         else:
             self.data = []
 
@@ -179,8 +175,7 @@ class CookerCustomizations:
         Octet 10 (ff): Favorite Cooking Minute in hex
         Octet 11-16 (01 00 00 00 1d 1f): Meaning unknown
         """
-        self.custom = [int(custom[i:i + 2], 16) for i in
-                       range(0, len(custom), 2)]
+        self.custom = [int(custom[i : i + 2], 16) for i in range(0, len(custom), 2)]
 
     @property
     def jingzhu_appointment(self) -> time:
@@ -210,18 +205,22 @@ class CookerCustomizations:
         return "".join(["{:02x}".format(value) for value in self.custom])
 
     def __repr__(self) -> str:
-        s = "<CookerCustomizations jingzhu_appointment=%s, " \
-            "kuaizhu_appointment=%s, " \
-            "zhuzhou_appointment=%s, " \
-            "zhuzhou_cooking=%s, " \
-            "favorite_appointment=%s, " \
-            "favorite_cooking=%s>" % \
-            (self.jingzhu_appointment,
-             self.kuaizhu_appointment,
-             self.zhuzhou_appointment,
-             self.zhuzhou_cooking,
-             self.favorite_appointment,
-             self.favorite_cooking)
+        s = (
+            "<CookerCustomizations jingzhu_appointment=%s, "
+            "kuaizhu_appointment=%s, "
+            "zhuzhou_appointment=%s, "
+            "zhuzhou_cooking=%s, "
+            "favorite_appointment=%s, "
+            "favorite_cooking=%s>"
+            % (
+                self.jingzhu_appointment,
+                self.kuaizhu_appointment,
+                self.zhuzhou_appointment,
+                self.zhuzhou_cooking,
+                self.favorite_appointment,
+                self.favorite_cooking,
+            )
+        )
         return s
 
 
@@ -270,53 +269,61 @@ class CookingStage:
     @property
     def name(self) -> str:
         try:
-            return COOKING_STAGES[self.state]['name']
+            return COOKING_STAGES[self.state]["name"]
         except KeyError:
-            return 'Unknown stage'
+            return "Unknown stage"
 
     @property
     def description(self) -> str:
         try:
-            return COOKING_STAGES[self.state]['description']
+            return COOKING_STAGES[self.state]["description"]
         except KeyError:
-            return ''
+            return ""
 
     @property
     def raw(self) -> str:
         return self.stage
 
     def __str__(self) -> str:
-        s = "name=%s, " \
-            "description=%s, " \
-            "state=%s, " \
-            "rice_id=%s, " \
-            "taste=%s, " \
-            "taste_phase=%s, " \
-            "raw=%s" % \
-            (self.name,
-             self.description,
-             self.state,
-             self.rice_id,
-             self.taste,
-             self.taste_phase,
-             self.raw)
+        s = (
+            "name=%s, "
+            "description=%s, "
+            "state=%s, "
+            "rice_id=%s, "
+            "taste=%s, "
+            "taste_phase=%s, "
+            "raw=%s"
+            % (
+                self.name,
+                self.description,
+                self.state,
+                self.rice_id,
+                self.taste,
+                self.taste_phase,
+                self.raw,
+            )
+        )
         return s
 
     def __repr__(self) -> str:
-        s = "<CookingStage name=%s, " \
-            "description=%s, " \
-            "state=%s, " \
-            "rice_id=%s, " \
-            "taste=%s, " \
-            "taste_phase=%s, " \
-            "raw=%s>" % \
-            (self.name,
-             self.description,
-             self.state,
-             self.rice_id,
-             self.taste,
-             self.taste_phase,
-             self.stage)
+        s = (
+            "<CookingStage name=%s, "
+            "description=%s, "
+            "state=%s, "
+            "rice_id=%s, "
+            "taste=%s, "
+            "taste_phase=%s, "
+            "raw=%s>"
+            % (
+                self.name,
+                self.description,
+                self.state,
+                self.rice_id,
+                self.taste,
+                self.taste_phase,
+                self.stage,
+            )
+        )
         return s
 
 
@@ -334,8 +341,9 @@ class InteractionTimeouts:
         if timeouts is None:
             self.timeouts = [5, 4, 15]
         else:
-            self.timeouts = [int(timeouts[i:i + 2], 16) for i in
-                             range(0, len(timeouts), 2)]
+            self.timeouts = [
+                int(timeouts[i : i + 2], 16) for i in range(0, len(timeouts), 2)
+            ]
 
     @property
     def led_off(self) -> int:
@@ -365,12 +373,12 @@ class InteractionTimeouts:
         return "".join(["{:02x}".format(value) for value in self.timeouts])
 
     def __repr__(self) -> str:
-        s = "<InteractionTimeouts led_off=%s, " \
-            "lid_open=%s, " \
-            "lid_open_warning=%s>" % \
-            (self.led_off,
-             self.lid_open,
-             self.lid_open_warning)
+        s = (
+            "<InteractionTimeouts led_off=%s, "
+            "lid_open=%s, "
+            "lid_open_warning=%s>"
+            % (self.led_off, self.lid_open, self.lid_open_warning)
+        )
         return s
 
 
@@ -398,8 +406,9 @@ class CookerSettings:
         if settings is None:
             self.settings = [0, 4]
         else:
-            self.settings = [int(settings[i:i + 2], 16) for i in
-                             range(0, len(settings), 2)]
+            self.settings = [
+                int(settings[i : i + 2], 16) for i in range(0, len(settings), 2)
+            ]
 
     @property
     def pressure_supported(self) -> bool:
@@ -504,24 +513,28 @@ class CookerSettings:
         return "".join(["{:02x}".format(value) for value in self.settings])
 
     def __repr__(self) -> str:
-        s = "<CookerSettings pressure_supported=%s, " \
-            "led_on=%s, " \
-            "lid_open_warning=%s, " \
-            "lid_open_warning_delayed=%s, " \
-            "auto_keep_warm=%s, " \
-            "jingzhu_auto_keep_warm=%s, " \
-            "kuaizhu_auto_keep_warm=%s, " \
-            "zhuzhou_auto_keep_warm=%s, " \
-            "favorite_auto_keep_warm=%s>" % \
-            (self.pressure_supported,
-             self.led_on,
-             self.lid_open_warning,
-             self.lid_open_warning_delayed,
-             self.auto_keep_warm,
-             self.jingzhu_auto_keep_warm,
-             self.kuaizhu_auto_keep_warm,
-             self.zhuzhou_auto_keep_warm,
-             self.favorite_auto_keep_warm)
+        s = (
+            "<CookerSettings pressure_supported=%s, "
+            "led_on=%s, "
+            "lid_open_warning=%s, "
+            "lid_open_warning_delayed=%s, "
+            "auto_keep_warm=%s, "
+            "jingzhu_auto_keep_warm=%s, "
+            "kuaizhu_auto_keep_warm=%s, "
+            "zhuzhou_auto_keep_warm=%s, "
+            "favorite_auto_keep_warm=%s>"
+            % (
+                self.pressure_supported,
+                self.led_on,
+                self.lid_open_warning,
+                self.lid_open_warning_delayed,
+                self.auto_keep_warm,
+                self.jingzhu_auto_keep_warm,
+                self.kuaizhu_auto_keep_warm,
+                self.zhuzhou_auto_keep_warm,
+                self.favorite_auto_keep_warm,
+            )
+        )
         return s
 
 
@@ -572,17 +585,17 @@ class CookerStatus:
     @property
     def mode(self) -> OperationMode:
         """Current operation mode."""
-        return OperationMode(self.data['func'])
+        return OperationMode(self.data["func"])
 
     @property
     def menu(self) -> int:
         """Selected recipe id."""
-        return int(self.data['menu'], 16)
+        return int(self.data["menu"], 16)
 
     @property
     def stage(self) -> Optional[CookingStage]:
         """Current stage if cooking."""
-        stage = self.data['stage']
+        stage = self.data["stage"]
         if len(stage) == 10:
             return CookingStage(stage)
 
@@ -595,7 +608,7 @@ class CookerStatus:
 
         Example values: *29*, 031e0b23, 031e0b23031e
         """
-        value = self.data['temp']
+        value = self.data["temp"]
         if len(value) == 2 and value.isdigit():
             return int(value)
 
@@ -609,7 +622,7 @@ class CookerStatus:
         The property "temp" is used for different purposes.
         Example values: 29, *031e0b23*, 031e0b23031e
         """
-        value = self.data['temp']
+        value = self.data["temp"]
         if len(value) == 8:
             return time(hour=int(value[4:6], 16), minute=int(value[6:8], 16))
 
@@ -618,12 +631,12 @@ class CookerStatus:
     @property
     def remaining(self) -> int:
         """Remaining minutes of the cooking process."""
-        return int(self.data['t_func'])
+        return int(self.data["t_func"])
 
     @property
     def cooking_delayed(self) -> Optional[int]:
         """Wait n minutes before cooking / scheduled cooking."""
-        delay = int(self.data['t_precook'])
+        delay = int(self.data["t_precook"])
 
         if delay >= 0:
             return delay
@@ -633,36 +646,36 @@ class CookerStatus:
     @property
     def duration(self) -> int:
         """Duration of the cooking process."""
-        return int(self.data['t_cook'])
+        return int(self.data["t_cook"])
 
     @property
     def settings(self) -> CookerSettings:
         """Settings of the cooker."""
-        return CookerSettings(self.data['setting'])
+        return CookerSettings(self.data["setting"])
 
     @property
     def interaction_timeouts(self) -> InteractionTimeouts:
         """Interaction timeouts."""
-        return InteractionTimeouts(self.data['delay'])
+        return InteractionTimeouts(self.data["delay"])
 
     @property
     def hardware_version(self) -> int:
         """Hardware version."""
-        return int(self.data['version'][0:4], 16)
+        return int(self.data["version"][0:4], 16)
 
     @property
     def firmware_version(self) -> int:
         """Firmware version."""
-        return int(self.data['version'][4:8], 16)
+        return int(self.data["version"][4:8], 16)
 
     @property
     def favorite(self) -> int:
         """Favored recipe id. Can be compared with the menu property."""
-        return int(self.data['favorite'], 16)
+        return int(self.data["favorite"], 16)
 
     @property
     def custom(self) -> Optional[CookerCustomizations]:
-        custom = self.data['custom']
+        custom = self.data["custom"]
 
         if len(custom) > 31:
             return CookerCustomizations(custom)
@@ -670,39 +683,44 @@ class CookerStatus:
         return None
 
     def __repr__(self) -> str:
-        s = "<CookerStatus mode=%s " \
-            "menu=%s, " \
-            "stage=%s, " \
-            "temperature=%s, " \
-            "start_time=%s" \
-            "remaining=%s, " \
-            "cooking_delayed=%s, " \
-            "cooking_temperature=%s, " \
-            "settings=%s, " \
-            "interaction_timeouts=%s, " \
-            "hardware_version=%s, " \
-            "firmware_version=%s, " \
-            "favorite=%s, " \
-            "custom=%s>" % \
-            (self.mode,
-             self.menu,
-             self.stage,
-             self.temperature,
-             self.start_time,
-             self.remaining,
-             self.cooking_delayed,
-             self.duration,
-             self.settings,
-             self.interaction_timeouts,
-             self.hardware_version,
-             self.firmware_version,
-             self.favorite,
-             self.custom)
+        s = (
+            "<CookerStatus mode=%s "
+            "menu=%s, "
+            "stage=%s, "
+            "temperature=%s, "
+            "start_time=%s"
+            "remaining=%s, "
+            "cooking_delayed=%s, "
+            "cooking_temperature=%s, "
+            "settings=%s, "
+            "interaction_timeouts=%s, "
+            "hardware_version=%s, "
+            "firmware_version=%s, "
+            "favorite=%s, "
+            "custom=%s>"
+            % (
+                self.mode,
+                self.menu,
+                self.stage,
+                self.temperature,
+                self.start_time,
+                self.remaining,
+                self.cooking_delayed,
+                self.duration,
+                self.settings,
+                self.interaction_timeouts,
+                self.hardware_version,
+                self.firmware_version,
+                self.favorite,
+                self.custom,
+            )
+        )
         return s
 
 
 class Cooker(Device):
     """Main class representing the cooker."""
+
     @command(
         default_output=format_output(
             "",
@@ -719,20 +737,32 @@ class Cooker(Device):
             "Hardware version: {result.hardware_version}\n"
             "Firmware version: {result.firmware_version}\n"
             "Favorite: {result.favorite}\n"
-            "Custom: {result.custom}\n"
+            "Custom: {result.custom}\n",
         )
     )
     def status(self) -> CookerStatus:
         """Retrieve properties."""
-        properties = ['func', 'menu', 'stage', 'temp', 't_func', 't_precook',
-                      't_cook', 'setting', 'delay', 'version', 'favorite', 'custom']
+        properties = [
+            "func",
+            "menu",
+            "stage",
+            "temp",
+            "t_func",
+            "t_precook",
+            "t_cook",
+            "setting",
+            "delay",
+            "version",
+            "favorite",
+            "custom",
+        ]
 
         """
         Some cookers doesn't support a list of properties here. Therefore "all" properties
         are requested. If the property count or order changes the property list above must
         be updated.
         """
-        values = self.send("get_prop", ['all'])
+        values = self.send("get_prop", ["all"])
 
         properties_count = len(properties)
         values_count = len(values)
@@ -740,10 +770,11 @@ class Cooker(Device):
             _LOGGER.debug(
                 "Count (%s) of requested properties does not match the "
                 "count (%s) of received values.",
-                properties_count, values_count)
+                properties_count,
+                values_count,
+            )
 
-        return CookerStatus(
-            defaultdict(lambda: None, zip(properties, values)))
+        return CookerStatus(defaultdict(lambda: None, zip(properties, values)))
 
     @command(
         click.argument("profile", type=str),
@@ -754,74 +785,66 @@ class Cooker(Device):
         if not self._validate_profile(profile):
             raise CookerException("Invalid cooking profile: %s" % profile)
 
-        self.send('set_start', [profile])
+        self.send("set_start", [profile])
 
-    @command(
-        default_output=format_output("Cooking stopped"),
-    )
+    @command(default_output=format_output("Cooking stopped"))
     def stop(self):
         """Stop cooking."""
-        self.send('set_func', ['end02'])
+        self.send("set_func", ["end02"])
 
-    @command(
-        default_output=format_output("Cooking stopped"),
-    )
+    @command(default_output=format_output("Cooking stopped"))
     def stop_outdated_firmware(self):
         """Stop cooking (obsolete)."""
-        self.send('set_func', ['end'])
+        self.send("set_func", ["end"])
 
-    @command(
-        default_output=format_output("Setting no warnings"),
-    )
+    @command(default_output=format_output("Setting no warnings"))
     def set_no_warnings(self):
         """Disable warnings."""
-        self.send('set_func', ['nowarn'])
+        self.send("set_func", ["nowarn"])
 
-    @command(
-        default_output=format_output("Setting acknowledge"),
-    )
+    @command(default_output=format_output("Setting acknowledge"))
     def set_acknowledge(self):
         """Enable warnings?"""
-        self.send('set_func', ['ack'])
+        self.send("set_func", ["ack"])
 
     # FIXME: Add unified CLI support
-    def set_interaction(self, settings: CookerSettings,
-                        timeouts: InteractionTimeouts):
+    def set_interaction(self, settings: CookerSettings, timeouts: InteractionTimeouts):
         """Set interaction. Supported by all cookers except MODEL_PRESS1"""
-        self.send('set_interaction',
-                  [str(settings),
-                   "{:x}".format(timeouts.led_off),
-                   "{:x}".format(timeouts.lid_open),
-                   "{:x}".format(timeouts.lid_open_warning)])
+        self.send(
+            "set_interaction",
+            [
+                str(settings),
+                "{:x}".format(timeouts.led_off),
+                "{:x}".format(timeouts.lid_open),
+                "{:x}".format(timeouts.lid_open_warning),
+            ],
+        )
 
     @command(
         click.argument("profile", type=str),
-        default_output=format_output("Setting menu to {profile}")
+        default_output=format_output("Setting menu to {profile}"),
     )
     def set_menu(self, profile: str):
         """Select one of the default(?) cooking profiles"""
         if not self._validate_profile(profile):
             raise CookerException("Invalid cooking profile: %s" % profile)
 
-        self.send('set_menu', [profile])
+        self.send("set_menu", [profile])
 
-    @command(
-        default_output=format_output(
-            "",
-            "Temperature history: {result}\n"
-        )
-    )
+    @command(default_output=format_output("", "Temperature history: {result}\n"))
     def get_temperature_history(self) -> TemperatureHistory:
         """Retrieves a temperature history.
 
         The temperature is only available while cooking.
         Approx. six data points per minute.
         """
-        data = self.send('get_temp_history')
+        data = self.send("get_temp_history")
 
         return TemperatureHistory(data[0])
 
     @staticmethod
     def _validate_profile(profile):
-        return all(c in string.hexdigits for c in profile) and \
-               len(profile) in [228, 242]
+        return all(c in string.hexdigits for c in profile) and len(profile) in [
+            228,
+            242,
+        ]
