@@ -3,8 +3,9 @@ from unittest import TestCase
 import pytest
 
 from miio import PhilipsMoonlight
-from miio.philips_moonlight import PhilipsMoonlightStatus, PhilipsMoonlightException
+from miio.philips_moonlight import PhilipsMoonlightException, PhilipsMoonlightStatus
 from miio.utils import int_to_rgb, rgb_to_int
+
 from .dummies import DummyDevice
 
 
